Package: ISAR
Type: Package
Title: Introduction to Sports Analytics using R (ISAR) Data
Version: 1.0.5
Authors@R: c(
    person("Ryan", "Elmore", email = "Ryan.Elmore@du.edu", role = c("cre", "aut")))
Maintainer: Ryan Elmore <Ryan.Elmore@du.edu>
Description: We provide data sets used in the textbook "Introduction to Sports Analytics using R" by Elmore and Urbaczweski (2025). 
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
Depends: R (>= 3.5)
RoxygenNote: 7.3.3
URL: https://github.com/rtelmore/ISAR
BugReports: https://github.com/rtelmore/ISAR/issues
NeedsCompilation: no
Packaged: 2026-04-21 19:23:42 UTC; ryanelmore
Author: Ryan Elmore [cre, aut]
Repository: CRAN
Date/Publication: 2026-04-21 22:32:20 UTC
Built: R 4.6.0; ; 2026-04-26 20:26:58 UTC; unix
