#' Draftkings Showdown Game (Clippers vs. Mavericks)
#'
#' A dataset containing the Draftkings salary information for Game 3 of the
#'  2021 NBA Playoffs between the Los Angeles Clippers and the Dallas Mavericks.
#'
#' @format A data frame with 68 rows and 9 variables:
#' \describe{
#'   \item{position}{real-life roster position of the player}
#'   \item{name_id}{player name and Draftkings ID}
#'   \item{name}{player name}
#'   \item{id}{Draftkings player ID}
#'   \item{roster_position}{Draftkings roster position}
#'   \item{salary}{player salary}
#'   \item{game_info}{game information for the players}
#'   \item{team_abbrev}{player team as an abbreviation}
#'   \item{avg_points_per_game}{player average Draftkings points per game}
#' }
#' @source Draftkings Contest Page
"dk_lac_dal"
