#' 2025 WNBA Seattle Storm Shots
#'
#' A dataset containing all Seattle Storm shots in the 2025 season
#'
#' @format A data frame with 6347 rows and 3 variables:
#' \describe{
#'.  \item{coordinate_x}{X Coordinate of Shot}
#'.  \item{coordinate_y}{Y Coordinate of Shot}
#'   \item{scoring_play}{Made or Missed Shot}
#' }
#' @source \url{https://wehoop.sportsdataverse.org}
"wnba_seattle_pbp_2025"
