#' 2022 Official World Golf Rankings
#'
#' A dataset containing the Official World Golf Rankings in June 2022
#'
#' @format A data frame with 300 rows and 2 variables:
#' \describe{
#'   \item{WGR_June_2022}{official golf world ranking}
#'   \item{Player_initial_last}{initial of first name and complete last name of player}
#' }
#' @source \url{https://www.owgr.com/archive/archive.sps?iType=1747}
"ow_golf_rankings"
