#' Draftkings Showdown Game in NHL (Edmonton Oilers versus Colorado Avalanche)
#'
#' A dataset containing the Draftkings salary information for Game 1 of the
#'  2022 NHL Playoffs between the Edmonton Oilers versus Colorado Avalanche.
#'
#' @format A data frame with 252 rows and 9 variables:
#' \describe{
#'   \item{position}{real-life roster position of the player}
#'   \item{name_id}{player name and Draftkings ID}
#'   \item{name}{player name}
#'   \item{id}{Draftkings player ID}
#'   \item{roster_position}{Draftkings roster position}
#'   \item{salary}{player salary}
#'   \item{game_info}{game information for the players}
#'   \item{team_abbrev}{player team as an abbreviation}
#'   \item{avg_points_per_game}{player average Draftkings points per game}
#' }
#' @source Draftkings Contest Page
"dk_edm_col"
