#' 2025 WNBA Player Shots
#'
#' A dataset containing Breanna Stewart and A'ja Wilson's WNBA shots in the 2025 season
#'
#' @format A data frame with 3297 rows and 3 variables:
#' \describe{
#'   \item{athlete_display_name}{Player name}
#'.  \item{coordinate_x}{X Coordinate of Shot}
#'.  \item{coordinate_y}{Y Coordinate of Shot}
#' }
#' @source \url{https://wehoop.sportsdataverse.org}
"wnba_player_shots_2025"
