#' NBA Four Factors (Team) for the 2023-24 Season
#'
#' A dataset containing the NBA Four Factor table on nba.com
#'
#' @format A data frame with 2460 rows and 14 variables:
#' \describe{
#'   \item{game_id}{Game ID on nba.com}
#'   \item{team_id}{Team ID on nba.com}
#'   \item{team_name}{Team name on nba.com}
#'   \item{team_abbreviation}{Team abbreviation on nba.com}
#'   \item{team_city}{Team city}
#'   \item{min}{Minutes in the game}
#'   \item{efg_pct}{Effective field goal percentage}
#'   \item{fta_rate}{Free throw rate of team}
#'   \item{tm_tov_pct}{Turnover percentage of opponent}
#'   \item{oreb_pct}{Offensive rebound percentage of opponent}
#'   \item{opp_efg_pct}{Effective field goal percentage of opponent}
#'   \item{opp_fta_rate}{Free throw rate of opponent}
#'   \item{opp_tov_pct}{Turnover percentage of opponent}
#'   \item{opp_oreb_pct}{Offensive rebound percentage of opponent}
#' }
#' @source \url{http://asbcllc.com/nbastatR/reference/box_scores.html}
"nba_ff_team_2024"
