---
name: Improvement
about: Suggest an improvement to existing functionality
title: ''
labels: improvement
assignees: ''

---

**Describe the improvement you would like to see**
A clear and concise description of the improvement proposal.

**How will this change existing functionality?**
A clear and concise description on how this will affect current functionality.

**How will this improvement affect the current Threat Model?**
Leave blank for maintainers to fill out if you are uncertain about this.
