% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/masters.R
\docType{data}
\name{masters}
\alias{masters}
\title{2019 Masters Tournament Scores}
\format{
A data frame with 87 rows and 9 variables:
\describe{
  \item{pos}{finishing position for a player}
  \item{player_name}{name of the golfer}
  \item{nationality}{nationality of the golfer}
  \item{score}{final score relative to par}
  \item{round_1}{number of strokes from the first round}
  \item{round_2}{number of strokes from the second round}
  \item{round_3}{number of strokes from the third round}
  \item{round_4}{number of strokes from the fourth round}
  \item{total}{total strokes from all rounds}
}
}
\source{
\url{https://www.sportingnews.com/us/golf/news/masters-leaderboard-2019-live-scores-results-sunday/n1j77sci339r1f60hm3e1ei17}
}
\usage{
masters
}
\description{
A dataset containing the scores from the 2019 Masters Golf Tournament.
}
\keyword{datasets}
